@@ -54,6 +54,10 @@ def docs():
         "[27] ssap.scatter03(df, parameter_x, parameter_y, category, title)\n"
         "[28] ssap.map()\n"
         "[29] ssap.map01(df, province, parameter_x, method)\n"
+        "[30] ssap.scatter04hist(df, parameter_x, parameter_y, bins, title)\n"
+        "[31] ssap.colorlist()\n"
+        "[32] ssap.colormap()\n"
+        "[33] ssap.scatter05box(df, parameter_x, parameter_y, title)\n"
     )
     # explain details:
     # print(
@@ -98,6 +102,7 @@ def cmd():
         "[8] df2.sort_values(by=['xxx'],inplace=True) | 'sort values'\n"
         "[9] set(df) | 'remove duplicate for one parameter'\n"
         "[10] df['new column'] = df['existing column'] + 100 | 'add a new column' \n"
+        "[11] pip show (package name)\n"
     )
 
 
@@ -1042,8 +1047,6 @@ def map01(df, province, parameter_x, method):
     # display(pdsmap)
 
 
-
-# >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> [to be validated. update:12/28]
 # scatter plot + hist plot on top/right.
 def scatter04hist(df, parameter_x, parameter_y, bins, title):
     import matplotlib.pyplot as plt
@@ -1102,10 +1105,6 @@ def scatter04hist(df, parameter_x, parameter_y, bins, title):
     plt.show()
 
 
-
-# show correlation line + error zone. with scatter plot:
-
-
 # show colormap detail:
 def colormap():
     import numpy as np
@@ -1166,7 +1165,7 @@ def colormap():
 
 
 # show colorbar detail:
-def colorbar():
+def colorlist():
 
     import matplotlib.pyplot as plt
     import matplotlib.colors as mcolors
@@ -1239,14 +1238,91 @@ def colorbar():
     plt.show()
 
 
+# scatter plot + box plot on top/right.
+def scatter05box(df, parameter_x, parameter_y, title):
+    import matplotlib.pyplot as plt
+
+    df = df
+    x = df[parameter_x]
+    y = df[parameter_y]
+    title = title
+
+    # definitions for the axes
+    left, width = 0.1, 0.65
+    bottom, height = 0.1, 0.65
+    spacing = 0.005
+
+    rect_scatter = [left, bottom, width, height]
+    rect_histx = [left, bottom + height + spacing, width, 0.08]
+    rect_histy = [left + width + spacing, bottom, 0.08, height]
+
+    # start with a rectangular Figure
+    plt.figure(figsize=(8, 8))
+
+    # scatter plot
+    ax_scatter = plt.axes(rect_scatter)
+    plt.grid(linestyle='--', lw=0.5)
+    ax_scatter.tick_params(direction='in', top=True, right=True)
+    plt.xlabel(parameter_x)
+    plt.ylabel(parameter_y)
+
+    # top hist
+    ax_histx = plt.axes(rect_histx)
+    plt.grid(linestyle='--', lw=0.5, axis='y')
+    ax_histx.tick_params(direction='in', labelbottom=False)
+    plt.xlabel(parameter_x)
+    #     plt.ylabel('Counts')
+    plt.title(title)
+
+    # right hist
+    ax_histy = plt.axes(rect_histy)
+    plt.grid(linestyle='--', lw=0.5, axis='x')
+    ax_histy.tick_params(direction='in', labelleft=False)
+    #     plt.xlabel('Counts')
+    plt.ylabel(parameter_y)
+
+    # the scatter plot:
+    ax_scatter.scatter(x, y, edgecolor='black', lw=0.5, alpha=0.7, facecolor='darkorange')
+
+    # now determine nice limits by hand:
+    #     ax_histx.hist(x, bins=bins,edgecolor='black',facecolor='darkorange',alpha=0.7)
+    #     ax_histy.hist(y, bins=bins, orientation='horizontal',edgecolor='black',facecolor='darkorange',alpha=0.7)
+
+    red_square = dict(markerfacecolor='lightgrey', marker='o', alpha=0.5, lw=1)
+
+    x = ax_histx.boxplot(x, flierprops=red_square, vert=False, widths=0.5, patch_artist=True)
+    for patch in x['boxes']:
+        patch.set_facecolor('orange')
+
+    y = ax_histy.boxplot(y, flierprops=red_square, widths=0.5, patch_artist=True)
+    for patch in y['boxes']:
+        patch.set_facecolor('orange')
+
+    #     ax_histx.set_xlim(ax_scatter.get_xlim())
+    #     ax_histy.set_ylim(ax_scatter.get_ylim())
+
+    plt.show()
+
+
+
+# >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> [to be validated. update:12/28]
+
+
+
+
+
+
+
+# show correlation line + error zone. with scatter plot:
+
+
 # [planning ↓]
 
-
-
 # heatmap() / correlation map
 # Line plot (x-时间序列: 4.移动平均图 Arima  5.时间序列预测 等种种）
 # my.data analytics ppt里的图表
 # 多因子相关性矩阵图/
 # SSAP用户报告里绘制的图
 # 多项式回归拟合
-# 聚类算法 DBSCAN.
\ No newline at end of file
+# 聚类算法 DBSCAN.
+# regression model:
\ No newline at end of file
